==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkLookupTable.java <==
// java wrapper for vtkLookupTable object
//

package vtk;
import vtk.*;

public class vtkLookupTable extends vtkScalarsToColors
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int IsOpaque_2();
  public int IsOpaque()
    { return IsOpaque_2(); }

  private native int Allocate_3(int id0,int id1);
  public int Allocate(int id0,int id1)
    { return Allocate_3(id0,id1); }

  private native void Build_4();
  public void Build()
    { Build_4(); }

  private native void ForceBuild_5();
  public void ForceBuild()
    { ForceBuild_5(); }

  private native void BuildSpecialColors_6();
  public void BuildSpecialColors()
    { BuildSpecialColors_6(); }

  private native void SetRamp_7(int id0);
  public void SetRamp(int id0)
    { SetRamp_7(id0); }

  private native void SetRampToLinear_8();
  public void SetRampToLinear()
    { SetRampToLinear_8(); }

  private native void SetRampToSCurve_9();
  public void SetRampToSCurve()
    { SetRampToSCurve_9(); }

  private native void SetRampToSQRT_10();
  public void SetRampToSQRT()
    { SetRampToSQRT_10(); }

  private native int GetRamp_11();
  public int GetRamp()
    { return GetRamp_11(); }

  private native void SetScale_12(int id0);
  public void SetScale(int id0)
    { SetScale_12(id0); }

  private native void SetScaleToLinear_13();
  public void SetScaleToLinear()
    { SetScaleToLinear_13(); }

  private native void SetScaleToLog10_14();
  public void SetScaleToLog10()
    { SetScaleToLog10_14(); }

  private native int GetScale_15();
  public int GetScale()
    { return GetScale_15(); }

  private native void SetTableRange_16(double id0[]);
  public void SetTableRange(double id0[])
    { SetTableRange_16(id0); }

  private native void SetTableRange_17(double id0,double id1);
  public void SetTableRange(double id0,double id1)
    { SetTableRange_17(id0,id1); }

  private native double[] GetTableRange_18();
  public double[] GetTableRange()
    { return GetTableRange_18(); }

  private native void SetHueRange_19(double id0,double id1);
  public void SetHueRange(double id0,double id1)
    { SetHueRange_19(id0,id1); }

  private native void SetHueRange_20(double id0[]);
  public void SetHueRange(double id0[])
    { SetHueRange_20(id0); }

  private native double[] GetHueRange_21();
  public double[] GetHueRange()
    { return GetHueRange_21(); }

  private native void SetSaturationRange_22(double id0,double id1);
  public void SetSaturationRange(double id0,double id1)
    { SetSaturationRange_22(id0,id1); }

  private native void SetSaturationRange_23(double id0[]);
  public void SetSaturationRange(double id0[])
    { SetSaturationRange_23(id0); }

  private native double[] GetSaturationRange_24();
  public double[] GetSaturationRange()
    { return GetSaturationRange_24(); }

  private native void SetValueRange_25(double id0,double id1);
  public void SetValueRange(double id0,double id1)
    { SetValueRange_25(id0,id1); }

  private native void SetValueRange_26(double id0[]);
  public void SetValueRange(double id0[])
    { SetValueRange_26(id0); }

  private native double[] GetValueRange_27();
  public double[] GetValueRange()
    { return GetValueRange_27(); }

  private native void SetAlphaRange_28(double id0,double id1);
  public void SetAlphaRange(double id0,double id1)
    { SetAlphaRange_28(id0,id1); }

  private native void SetAlphaRange_29(double id0[]);
  public void SetAlphaRange(double id0[])
    { SetAlphaRange_29(id0); }

  private native double[] GetAlphaRange_30();
  public double[] GetAlphaRange()
    { return GetAlphaRange_30(); }

  private native void SetNanColor_31(double id0,double id1,double id2,double id3);
  public void SetNanColor(double id0,double id1,double id2,double id3)
    { SetNanColor_31(id0,id1,id2,id3); }

  private native void SetNanColor_32(double id0[]);
  public void SetNanColor(double id0[])
    { SetNanColor_32(id0); }

  private native double[] GetNanColor_33();
  public double[] GetNanColor()
    { return GetNanColor_33(); }

  private native void SetBelowRangeColor_34(double id0,double id1,double id2,double id3);
  public void SetBelowRangeColor(double id0,double id1,double id2,double id3)
    { SetBelowRangeColor_34(id0,id1,id2,id3); }

  private native void SetBelowRangeColor_35(double id0[]);
  public void SetBelowRangeColor(double id0[])
    { SetBelowRangeColor_35(id0); }

  private native double[] GetBelowRangeColor_36();
  public double[] GetBelowRangeColor()
    { return GetBelowRangeColor_36(); }

  private native void SetUseBelowRangeColor_37(int id0);
  public void SetUseBelowRangeColor(int id0)
    { SetUseBelowRangeColor_37(id0); }

  private native int GetUseBelowRangeColor_38();
  public int GetUseBelowRangeColor()
    { return GetUseBelowRangeColor_38(); }

  private native void UseBelowRangeColorOn_39();
  public void UseBelowRangeColorOn()
    { UseBelowRangeColorOn_39(); }

  private native void UseBelowRangeColorOff_40();
  public void UseBelowRangeColorOff()
    { UseBelowRangeColorOff_40(); }

  private native void SetAboveRangeColor_41(double id0,double id1,double id2,double id3);
  public void SetAboveRangeColor(double id0,double id1,double id2,double id3)
    { SetAboveRangeColor_41(id0,id1,id2,id3); }

  private native void SetAboveRangeColor_42(double id0[]);
  public void SetAboveRangeColor(double id0[])
    { SetAboveRangeColor_42(id0); }

  private native double[] GetAboveRangeColor_43();
  public double[] GetAboveRangeColor()
    { return GetAboveRangeColor_43(); }

  private native void SetUseAboveRangeColor_44(int id0);
  public void SetUseAboveRangeColor(int id0)
    { SetUseAboveRangeColor_44(id0); }

  private native int GetUseAboveRangeColor_45();
  public int GetUseAboveRangeColor()
    { return GetUseAboveRangeColor_45(); }

  private native void UseAboveRangeColorOn_46();
  public void UseAboveRangeColorOn()
    { UseAboveRangeColorOn_46(); }

  private native void UseAboveRangeColorOff_47();
  public void UseAboveRangeColorOff()
    { UseAboveRangeColorOff_47(); }

  private native void GetColor_48(double id0,double id1[]);
  public void GetColor(double id0,double id1[])
    { GetColor_48(id0,id1); }

  private native double GetOpacity_49(double id0);
  public double GetOpacity(double id0)
    { return GetOpacity_49(id0); }

  private native int GetIndex_50(double id0);
  public int GetIndex(double id0)
    { return GetIndex_50(id0); }

  private native void SetNumberOfTableValues_51(int id0);
  public void SetNumberOfTableValues(int id0)
    { SetNumberOfTableValues_51(id0); }

  private native int GetNumberOfTableValues_52();
  public int GetNumberOfTableValues()
    { return GetNumberOfTableValues_52(); }

  private native void SetTableValue_53(int id0,double id1[]);
  public void SetTableValue(int id0,double id1[])
    { SetTableValue_53(id0,id1); }

  private native void SetTableValue_54(int id0,double id1,double id2,double id3,double id4);
  public void SetTableValue(int id0,double id1,double id2,double id3,double id4)
    { SetTableValue_54(id0,id1,id2,id3,id4); }

  private native double[] GetTableValue_55(int id0);
  public double[] GetTableValue(int id0)
    { return GetTableValue_55(id0); }

  private native void GetTableValue_56(int id0,double id1[]);
  public void GetTableValue(int id0,double id1[])
    { GetTableValue_56(id0,id1); }

  private native double[] GetRange_57();
  public double[] GetRange()
    { return GetRange_57(); }

  private native void SetRange_58(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_58(id0,id1); }

  private native void SetRange_59(double id0[]);
  public void SetRange(double id0[])
    { SetRange_59(id0); }

  private native void GetLogRange_60(double id0[],double id1[]);
  public void GetLogRange(double id0[],double id1[])
    { GetLogRange_60(id0,id1); }

  private native double ApplyLogScale_61(double id0,double id1[],double id2[]);
  public double ApplyLogScale(double id0,double id1[],double id2[])
    { return ApplyLogScale_61(id0,id1,id2); }

  private native void SetNumberOfColors_62(int id0);
  public void SetNumberOfColors(int id0)
    { SetNumberOfColors_62(id0); }

  private native int GetNumberOfColorsMinValue_63();
  public int GetNumberOfColorsMinValue()
    { return GetNumberOfColorsMinValue_63(); }

  private native int GetNumberOfColorsMaxValue_64();
  public int GetNumberOfColorsMaxValue()
    { return GetNumberOfColorsMaxValue_64(); }

  private native int GetNumberOfColors_65();
  public int GetNumberOfColors()
    { return GetNumberOfColors_65(); }

  private native void SetTable_66(vtkUnsignedCharArray id0);
  public void SetTable(vtkUnsignedCharArray id0)
    { SetTable_66(id0); }

  private native long GetTable_67();
  public vtkUnsignedCharArray GetTable() {
    long temp = GetTable_67();

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void DeepCopy_68(vtkScalarsToColors id0);
  public void DeepCopy(vtkScalarsToColors id0)
    { DeepCopy_68(id0); }

  private native int UsingLogScale_69();
  public int UsingLogScale()
    { return UsingLogScale_69(); }

  private native int GetNumberOfAvailableColors_70();
  public int GetNumberOfAvailableColors()
    { return GetNumberOfAvailableColors_70(); }

  private native void GetIndexedColor_71(int id0,double id1[]);
  public void GetIndexedColor(int id0,double id1[])
    { GetIndexedColor_71(id0,id1); }

  public vtkLookupTable() { super(); }

  public vtkLookupTable(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkLookupTable.java <==
// java wrapper for vtkLookupTable object
//

package vtk;
import vtk.*;

public class vtkLookupTable extends vtkScalarsToColors
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int IsOpaque_2();
  public int IsOpaque()
    { return IsOpaque_2(); }

  private native int Allocate_3(int id0,int id1);
  public int Allocate(int id0,int id1)
    { return Allocate_3(id0,id1); }

  private native void Build_4();
  public void Build()
    { Build_4(); }

  private native void ForceBuild_5();
  public void ForceBuild()
    { ForceBuild_5(); }

  private native void BuildSpecialColors_6();
  public void BuildSpecialColors()
    { BuildSpecialColors_6(); }

  private native void SetRamp_7(int id0);
  public void SetRamp(int id0)
    { SetRamp_7(id0); }

  private native void SetRampToLinear_8();
  public void SetRampToLinear()
    { SetRampToLinear_8(); }

  private native void SetRampToSCurve_9();
  public void SetRampToSCurve()
    { SetRampToSCurve_9(); }

  private native void SetRampToSQRT_10();
  public void SetRampToSQRT()
    { SetRampToSQRT_10(); }

  private native int GetRamp_11();
  public int GetRamp()
    { return GetRamp_11(); }

  private native void SetScale_12(int id0);
  public void SetScale(int id0)
    { SetScale_12(id0); }

  private native void SetScaleToLinear_13();
  public void SetScaleToLinear()
    { SetScaleToLinear_13(); }

  private native void SetScaleToLog10_14();
  public void SetScaleToLog10()
    { SetScaleToLog10_14(); }

  private native int GetScale_15();
  public int GetScale()
    { return GetScale_15(); }

  private native void SetTableRange_16(double id0[]);
  public void SetTableRange(double id0[])
    { SetTableRange_16(id0); }

  private native void SetTableRange_17(double id0,double id1);
  public void SetTableRange(double id0,double id1)
    { SetTableRange_17(id0,id1); }

  private native double[] GetTableRange_18();
  public double[] GetTableRange()
    { return GetTableRange_18(); }

  private native void SetHueRange_19(double id0,double id1);
  public void SetHueRange(double id0,double id1)
    { SetHueRange_19(id0,id1); }

  private native void SetHueRange_20(double id0[]);
  public void SetHueRange(double id0[])
    { SetHueRange_20(id0); }

  private native double[] GetHueRange_21();
  public double[] GetHueRange()
    { return GetHueRange_21(); }

  private native void SetSaturationRange_22(double id0,double id1);
  public void SetSaturationRange(double id0,double id1)
    { SetSaturationRange_22(id0,id1); }

  private native void SetSaturationRange_23(double id0[]);
  public void SetSaturationRange(double id0[])
    { SetSaturationRange_23(id0); }

  private native double[] GetSaturationRange_24();
  public double[] GetSaturationRange()
    { return GetSaturationRange_24(); }

  private native void SetValueRange_25(double id0,double id1);
  public void SetValueRange(double id0,double id1)
    { SetValueRange_25(id0,id1); }

  private native void SetValueRange_26(double id0[]);
  public void SetValueRange(double id0[])
    { SetValueRange_26(id0); }

  private native double[] GetValueRange_27();
  public double[] GetValueRange()
    { return GetValueRange_27(); }

  private native void SetAlphaRange_28(double id0,double id1);
  public void SetAlphaRange(double id0,double id1)
    { SetAlphaRange_28(id0,id1); }

  private native void SetAlphaRange_29(double id0[]);
  public void SetAlphaRange(double id0[])
    { SetAlphaRange_29(id0); }

  private native double[] GetAlphaRange_30();
  public double[] GetAlphaRange()
    { return GetAlphaRange_30(); }

  private native void SetNanColor_31(double id0,double id1,double id2,double id3);
  public void SetNanColor(double id0,double id1,double id2,double id3)
    { SetNanColor_31(id0,id1,id2,id3); }

  private native void SetNanColor_32(double id0[]);
  public void SetNanColor(double id0[])
    { SetNanColor_32(id0); }

  private native double[] GetNanColor_33();
  public double[] GetNanColor()
    { return GetNanColor_33(); }

  private native void SetBelowRangeColor_34(double id0,double id1,double id2,double id3);
  public void SetBelowRangeColor(double id0,double id1,double id2,double id3)
    { SetBelowRangeColor_34(id0,id1,id2,id3); }

  private native void SetBelowRangeColor_35(double id0[]);
  public void SetBelowRangeColor(double id0[])
    { SetBelowRangeColor_35(id0); }

  private native double[] GetBelowRangeColor_36();
  public double[] GetBelowRangeColor()
    { return GetBelowRangeColor_36(); }

  private native void SetUseBelowRangeColor_37(int id0);
  public void SetUseBelowRangeColor(int id0)
    { SetUseBelowRangeColor_37(id0); }

  private native int GetUseBelowRangeColor_38();
  public int GetUseBelowRangeColor()
    { return GetUseBelowRangeColor_38(); }

  private native void UseBelowRangeColorOn_39();
  public void UseBelowRangeColorOn()
    { UseBelowRangeColorOn_39(); }

  private native void UseBelowRangeColorOff_40();
  public void UseBelowRangeColorOff()
    { UseBelowRangeColorOff_40(); }

  private native void SetAboveRangeColor_41(double id0,double id1,double id2,double id3);
  public void SetAboveRangeColor(double id0,double id1,double id2,double id3)
    { SetAboveRangeColor_41(id0,id1,id2,id3); }

  private native void SetAboveRangeColor_42(double id0[]);
  public void SetAboveRangeColor(double id0[])
    { SetAboveRangeColor_42(id0); }

  private native double[] GetAboveRangeColor_43();
  public double[] GetAboveRangeColor()
    { return GetAboveRangeColor_43(); }

  private native void SetUseAboveRangeColor_44(int id0);
  public void SetUseAboveRangeColor(int id0)
    { SetUseAboveRangeColor_44(id0); }

  private native int GetUseAboveRangeColor_45();
  public int GetUseAboveRangeColor()
    { return GetUseAboveRangeColor_45(); }

  private native void UseAboveRangeColorOn_46();
  public void UseAboveRangeColorOn()
    { UseAboveRangeColorOn_46(); }

  private native void UseAboveRangeColorOff_47();
  public void UseAboveRangeColorOff()
    { UseAboveRangeColorOff_47(); }

  private native void GetColor_48(double id0,double id1[]);
  public void GetColor(double id0,double id1[])
    { GetColor_48(id0,id1); }

  private native double GetOpacity_49(double id0);
  public double GetOpacity(double id0)
    { return GetOpacity_49(id0); }

  private native int GetIndex_50(double id0);
  public int GetIndex(double id0)
    { return GetIndex_50(id0); }

  private native void SetNumberOfTableValues_51(int id0);
  public void SetNumberOfTableValues(int id0)
    { SetNumberOfTableValues_51(id0); }

  private native int GetNumberOfTableValues_52();
  public int GetNumberOfTableValues()
    { return GetNumberOfTableValues_52(); }

  private native void SetTableValue_53(int id0,double id1[]);
  public void SetTableValue(int id0,double id1[])
    { SetTableValue_53(id0,id1); }

  private native void SetTableValue_54(int id0,double id1,double id2,double id3,double id4);
  public void SetTableValue(int id0,double id1,double id2,double id3,double id4)
    { SetTableValue_54(id0,id1,id2,id3,id4); }

  private native double[] GetTableValue_55(int id0);
  public double[] GetTableValue(int id0)
    { return GetTableValue_55(id0); }

  private native void GetTableValue_56(int id0,double id1[]);
  public void GetTableValue(int id0,double id1[])
    { GetTableValue_56(id0,id1); }

  private native double[] GetRange_57();
  public double[] GetRange()
    { return GetRange_57(); }

  private native void SetRange_58(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_58(id0,id1); }

  private native void SetRange_59(double id0[]);
  public void SetRange(double id0[])
    { SetRange_59(id0); }

  private native void GetLogRange_60(double id0[],double id1[]);
  public void GetLogRange(double id0[],double id1[])
    { GetLogRange_60(id0,id1); }

  private native double ApplyLogScale_61(double id0,double id1[],double id2[]);
  public double ApplyLogScale(double id0,double id1[],double id2[])
    { return ApplyLogScale_61(id0,id1,id2); }

  private native void SetNumberOfColors_62(int id0);
  public void SetNumberOfColors(int id0)
    { SetNumberOfColors_62(id0); }

  private native int GetNumberOfColorsMinValue_63();
  public int GetNumberOfColorsMinValue()
    { return GetNumberOfColorsMinValue_63(); }

  private native int GetNumberOfColorsMaxValue_64();
  public int GetNumberOfColorsMaxValue()
    { return GetNumberOfColorsMaxValue_64(); }

  private native int GetNumberOfColors_65();
  public int GetNumberOfColors()
    { return GetNumberOfColors_65(); }

  private native void SetTable_66(vtkUnsignedCharArray id0);
  public void SetTable(vtkUnsignedCharArray id0)
    { SetTable_66(id0); }

  private native long GetTable_67();
  public vtkUnsignedCharArray GetTable() {
    long temp = GetTable_67();

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void DeepCopy_68(vtkScalarsToColors id0);
  public void DeepCopy(vtkScalarsToColors id0)
    { DeepCopy_68(id0); }

  private native int UsingLogScale_69();
  public int UsingLogScale()
    { return UsingLogScale_69(); }

  private native int GetNumberOfAvailableColors_70();
  public int GetNumberOfAvailableColors()
    { return GetNumberOfAvailableColors_70(); }

  private native void GetIndexedColor_71(int id0,double id1[]);
  public void GetIndexedColor(int id0,double id1[])
    { GetIndexedColor_71(id0,id1); }

  public vtkLookupTable() { super(); }

  public vtkLookupTable(long id) { super(id); }
  public native long   VTKInit();

}
